@@ -23,9 +23,10 @@
 #define WINPR_HAVE_GETPWUID_R
 #define WINPR_HAVE_STRNDUP
 #define WINPR_HAVE_UNWIND_H
+#define WINPR_HAVE_SSIZE_T
 #define WINPR_WITH_PNG
 
-/* #undef WINPR_HAVE_STRERROR_R */
+#define WINPR_HAVE_STRERROR_R /** @since version 3.3.0 */
 
 #define WITH_EVENTFD_READ_WRITE
 
@@ -34,15 +35,15 @@
 /* #undef WITH_INTERNAL_MD4 */
 /* #undef WITH_INTERNAL_MD5 */
 
-#define WITH_WINPR_JSON
+#define WITH_WINPR_JSON /** @since version 3.6.0 */
 
 /* #undef WITH_DEBUG_NTLM */
 /* #undef WITH_DEBUG_THREADS */
 /* #undef WITH_DEBUG_EVENTS */
 /* #undef WITH_DEBUG_MUTEX */
 
-#define WINPR_UTILS_IMAGE_WEBP
-#define WINPR_UTILS_IMAGE_PNG
-#define WINPR_UTILS_IMAGE_JPEG
+#define WINPR_UTILS_IMAGE_WEBP /** @since version 3.3.0 */
+#define WINPR_UTILS_IMAGE_PNG /** @since version 3.3.0 */
+#define WINPR_UTILS_IMAGE_JPEG /** @since version 3.3.0 */
 
 #endif /* WINPR_CONFIG_H */
